@@ -20,3 +20,6 @@ INSTALLED_APPS.insert(0, n3)
 TEMPLATE_DIRS.insert(0, n3 + '/templates')
 
 ROOT_URLCONF = '%s.urls' % (n3)
+
+STATIC_ROOT = os.path.join(p2,'static/')
+STATIC_URL = '/static/'
